@@ -102,12 +102,11 @@ def search_animeout(session, query):
 def search_animixplay(session, query):
     parsed = htmlparser.fromstring(
         session.post("https://cachecow.eu/api/search", data={"qfast": query})
-        .json()
-        .get("result")
+        .json()["result"]
         or "<div></div>"
     )
-
-    for results in parsed.cssselect(".name > a"):
+    
+    for results in parsed.cssselect("a[title]"):
         yield {
             "anime_url": ANIMIXPLAY[:-1] + results.get("href"),
             "name": results.get("title"),
